## Community Inclusion Currencies (CICs)


## Funding Sustainable Development Goals

**Last updated: 30-Sept-2019**

_Keywords: User Generated Tokens, Blockchain Community Currencies, Bonding Curves, Proof of Impact, Poverty Alleviation, Grassroots Economics, Sustainable Development Goals, Cash Transfer, Cash and Voucher Assistance_

**Abstract**

This paper proposes the development and expansion of networks of connected currencies (Community Inclusion Currencies (CICs)) comprising an open and decentralized monetary system as well as the protocols and architecture to support social and monetary development worldwide, and thereby contribute to achieving the United Nations’ Sustainable Development Goals (SDGs). We examine current programs in Kenya that utilize blockchain technologies in order to enable underserved communities to create currencies freely, securely, and with the inherent ability to connect their currencies to each other and propose a path toward technology diffusion. 


## 


[TOC]



## 1. Introduction


### 1.1 Background

The availability of national currency in a marginalized communities often bears little relation to the demand or capacity of local production, but derives from external factors such as the national debt, interest rates, trade deficits, regional crisis and IMF ascribed policies. The resulting scarcity of a medium of exchange invariably cripples communities’ internal trade and causes local markets to become chronically unstable. Poverty is often wrongly equated with simple lack of money rather than lack of opportunity. It is a structural issue caused by many factors, one of which is lack of liquidity. This factor alone can cause markets to stagnate, robbing people opportunities for growth that could exist within the community itself. 

Using markets as a way of alleviating poverty and empowering people out of shocks is increasingly becoming more common. There is a wide spectrum in which markets can be used to alleviate needs, cash and voucher assistance is one that is commonly used to increase vulnerable people's access to markets. Giving people money instead of in-kind assistance so they can decide what they need, has grown exponentially in the last 10 years. While the move has been transformational and desirable,  evidence has shown that it still lacks the sustainability to tackle the root causes of poverty that made people vulnerable in the first place. When tackling poverty as an institutional problem, standard development practices often miss a key component, currency design, causing income and profits to be extracted and accumulate with financiers in cities away from rural environments. In this environment National Currencies given directly to beneficiaries often stay in local circulation only for a limited time. 

In part due to the poor circulation of conventional currencies, the majority of economies worldwide are reported to be in decline and stagnation as local industries are lost or fail to materialise and large-scale market forces, such as high-interest-bearing debt, drive inequality (Ryan-Collins et al. 2012). At around $3 USD per day of trade per household, resource mobilization in Kenya is extremely low. The market in Kenya referenced further in this paper, much like other economically marginalized areas worldwide, is characterized by dramatic swings in productivity and stagnation influenced by seasonal markets, natural disasters, politics, and transnational markets.

This paper proposes reinventing cash and voucher assistance programs so they act as a catalyst for sustainable growth for communities. We propose creating community currencies using blockchain technology to create inclusive and empowering eco-systems that enables communities to develop and trade their own form of credit backed by their own productive capacity and seeded by local governments and the aid industry.

Jane Jacobs (1987) referred to the local market economy, rather than the national economy as the salient economic unit. A market economy can in turn be considered as a group of interacting economic nodes that combine into a network. The salient market unit here can be viewed as a **community**, a network that cares for its member nodes (businesses, producers and people). A **currency**, in this light, acts as both a promissory note for the work or future production within that network and a medium through which its members interact. A **community currency** can be considered a medium of exchange whose total value acts as a measure for the productive capacity of a community. 

Various models of complementary or community currencies have historically and currently emerged worldwide in response to the series of financial crises. The literature examining models of community currency, through both empirical evidence and simulations, have shown that CCs have the capability to stabilize local economic systems. In particular, local credit-clearing unions for local exchanges have been verified to stabilize trade while reducing the effects of simultaneous credit crunches. 

According to Hirota (2013), many types of community currencies have been issued and utilized since the 1980s. He describes a Community Currency as having the following distinguishing characteristics: (a) it is issued by a community organization; (b) it cannot be used outside the community; (c) it has a zero (or negative) interest rate; (d) it encourages community members to help each other. In Kobayashi et al., (2013), Nishibe sees community currencies as integrative media of exchange that promote revitalization of the local economy and encourage community activities. Barinaga et al. (2018) understands community currencies as local monetary infrastructures for community economies. 

In the late 1990s through the early 2000s, hundreds of CCs started to appear worldwide according to Lietaer (2004). However, many CCs have failed to scale or have simply not flourished. Yamazaki (2013) points out that about 60% of community currencies in Japan were terminated or suspended because of circulation failure due to lack of general market acceptance. We propose the use of blockchain technology, bonding curves to underlying contract and connecting protocols to create markets of CCs and mitigate the risk.


### 1.2 Community Currencies (CCs)

CCs seek to enable communities to develop a source of local credit based on productive capacity and local values, creating a monetary system better suited to eradicate poverty and the multiple indicators of deprivation targeted by the UN’s SDGs (See section 3.2.1  Proof of Impact for SDGs).

The findings of Stodder (2011) suggest that endogenous sources of credit through circulating vouchers, referred to as Community Currency (CC), can counteract seasonal conditions and increase overall trade volume. Historically CCs have not been able to expand (and stay automonouse) to include the 2+ billion people living in poverty for several reasons, particularly the inability to exchange CCs easily among more businesses and neighboring communities, hence limiting local economic development. In Kenya, Grassroots Economics Foundation has introduced CCs that have been used in roughly 4,500 businesses and schools among communities of over 200,000 people showing that this challenge is surmountable and the model is scalable if CCs can be built in a decentralized manner.

CICs proposed here build on the lessons learnt from the [Sarafu-Network](https://en.wikipedia.org/wiki/Sarafu-Credit), (a.k.a. Sarafu); _n.b. Sarafu means currency in Swahili._ Sarafu represents a particular model of Community Currency developed by [Grassroots Economics Foundation](https://www.grassrootseconomics.org/) in Kenya, in circulation since 2010. The Community Currencies using this model have stabilized seasonal markets (Ruddick et al. 2015) by injecting a new medium of exchange that is more readily available and circulates locally more than national currency. An initial pilot that connects CICs called Sarafu Network, through a participatory community approach, has converted Kenyan paper-based CCs into digital CICs, enabling CICs to combine together to grow their markets. This digital pilot started Q4 2018 has enabled over 70,000 transactions so far with over 5,500 accounts. This trade has been measured in the following categories: Food, Labour, Education, General shops, Energy, Water, Transport, Environment, Health. [Transaction and Impact data is available on GitHub. [https://github.com/GrassrootsEconomics](https://github.com/GrassrootsEconomics)]

Grassroots Economics Foundation in Kenya, is among a growing worldwide movement of community currency proponents who see a connected and decentralized economy as one of the most fundamental building blocks for designing a better future for humanity. In order to seed communities **_of_** currencies worldwide and promote equitability and stability, Grassroots Economics seeks to enable and support CICs for marginalized communities. 


### 1.3 Grassroots Economies

By enabling communities as the basic units of the economy to create their own currency, and groups of these currencies together to form super clusters for physical regions or causes, we are encouraging a decentralized bottom-up economy to emerge. The unit of exchange in this multitudinous currency environment is based on the productive capacity each currency represents, whose exchange value is determined by a market of such connected currencies. This community-level of granularity in the backing of each currency unit is currently impossible via non-blockchain based national currencies, as they do not effectively audit or react to the difference in supply of the medium of exchange vs available productive capacity. In other words, the increased issuance of national currency, largely through private banking insurance rates, does not adequately reflect actual productive capacity, as seen by the large growth in the credit supply vs gross national production (Ryan-Collins et al. 2012).

Before they are connected together, the liquidity of historic community currencies has been limited to the productivity of that particular local economy. Limiting the utility of the currency exclusively to services provided in the community can cause the CC to accumulate in hands that would struggle to spend them quickly enough. Additionally, if the CC is not convertible to national fiat currencies, local business would be challenged to offer products and services that have hard/external costs. Exchange protocols on a blockchain enable community currencies varying degrees of connectivity to other community currencies as well as national fiat currencies, providing adequate liquidity for large transaction volumes. Building on this fundamental connection between currencies, currency and software developers can build governance and collateral systems that safeguard their communities’ markets and wealth (see section 3 on Use Cases). Free competition among CICs can be seen as the fruition of Hayek’s (1990) proposal for competitively issued private currencies.

National currencies, which are currently described by Lietaer, et al. (2012) as dominant monocultures, may begin to adopt their own CIC systems for fractional reserve as a means of stabilizing such user-generated credit creation. Likewise communities will be able to create endogenous sources of credit to trade among each other and with fiat currencies based on their own productive capacity.


## 2. Tokenomics

Drawing on economics and game theory, the field of tokenomics is loosely defined as the emerging economics of cryptography-based tokens and networks. This paper discusses the current and future tokenomic configurations which allows any entity to issue CIC tokens that benefit from continuous on-chain liquidity and price-discovery, regardless of their scale and volume.  


### 2.1 Communities of Currencies

**_How do we enable community currencies to exchange with each other in an emergent ecosystem of individual, group, business, charity, and governmental tokens while preserving fair and balanced pricing of the currencies at the lowest possible costs?_**

The CICs currently implemented in Kenya are established with a [connecting exchange protocol](https://github.com/GrassrootsEconomics/CIC-Liquid-Token) (built into their smart contract). This exchange protocol includes a bonding curve (that connects CICs to their reserves) and is described in the [Bancor White Paper](http://about.bancor.network). Such tokens are linked to each other by staking a common token into their “reserve”. If two tokens (smart contracts) with this exchange protocol and share the same reserve (or a reserve of a reserve and so on, with a common token) the protocol is able to create an automatic exchange ratio between the two tokens. This enables community currencies built with such a protocol to interact with their neighbor by choosing or establishing common reserves. 

These reserve tokens that link community currencies together need not be tradable outside the regional network, but can optionally be connected to other reserves in a fractal-like manner and/or national currencies. The exchange protocol automates the price discovery of connected CICs as a function of their imports relative to their exports. In effect, using the protocol when converting from one token (A) into another (B) drives up supply and the relative price of B to A by adjusting the reserve balance of each CIC. 

A network of exchange protocol (bonding curve) connected CICs, when used as a medium of exchange, can be seen as a **Network _of_ Currencies**. These currency networks have the potential, as an emergent phenomenon, to create connected and decentralized economic systems. It is important to realize that CICs as well as networks of CICs are not necessarily decentralized - CCs are historically often single issuer (albeit potentially a cooperative or trusted single issuer) hence highly centralized, and lack scalability according to North (2005) for this reason. It is a network of networks _of_ these connected community currencies that begins to truly differentiate itself from isolated community currency systems or centralized exchanges or centralized network tokens, and provide adequate market acceptance, based in shared protocols for relative value.


### 2.2 Currency Creation

A community group may create a [CIC Liquid Token Contract](https://github.com/GrassrootsEconomics/CIC-Liquid-Token) on a blockchain (via a mobile interface) which can be created with an initial supply and made available and tradable for community members only or open to the broader world for transactions. If the created token has no initial reserve it can only be traded as an internal community currency, with no defined rate of exchange for other currencies. The token creator may airdrop (offer free promotional) tokens to community members or spend them into existence in various ways, as has been demonstrated with CCs in [Kenya](http://grassecon.org). A CIC creator may then connect with another CIC by establishing a _reserve _that is connected to both CICs. Note that a reserve token can be another Community Inclusion Currency that can be created by one or more parties and itself could be a usable medium of exchange and connected to a stable token (and hence national currencies). A large network of CICs connecting to one another acts as a decentralized buffer system, such that if any one currency is in decline, another can pick up its reserve, ensuring that communities’ collective production remains the source of all currency as these networks spread.	

In this way a currency creator creating a CIC as a promise for their future production is essentially issuing a voucher that can be spent or gifted into circulation. Alone, this token could fulfill many functions, but when attached to a reserve common to another token, a larger market is formed between the two currency creators. This bottom-up growth can expand into super networks of connected communities as nodes. This decentralized, bottom-up structure can form into regional and even global economies where the fundamental units are based on the value of the smallest element (the individual token’s promise for future production).

CIC reserve tokens can in turn contain a token which is linked to National Currencies and provide market liquidity by acting as reserves for many CICs. These group or village CICs can in turn act as reserves for other villages or projects. Group token creators can choose to create reserves between themselves only (no connection to national currency) and isolated tokens can remain completely isolated and non exchangeable, or eventually choose to connect to other tokens or networks of tokens. Token holders can have and trade with any token, but only those tokens linked through their reserves, directly or indirectly, can be exchanged for each other. In practice users auto-convert incoming tokens to a single ‘community’ token of their choosing.


### 2.3 Blockchain-Enabled Community Currencies

In order to implement Community Inclusion Currencies (CICs) in a framework that will allow them to interact with each other, the solutions currently available lie in decentralized ledger systems or blockchains and embedded smart contracts. Blockchains, due to their distributed nature and integrated cryptography, enable CC transactions records to be immutable and secure. They also offer the ability to encode scripts or programs into tokens called smart contracts. The CIC exchange protocol is one such open-source script embedded into the smart contract of Community Inclusion Currencies (CICs) which enable them to interact with each other. 

While a CIC could exist on any smart-contract-enabled blockchain, many blockchains charge high fees for executing transactions to the network. In order to trade effectively in marginalized communities, transaction fees must be minimized, which is why we are using the POA.Network blockchain, an Ethereum-based platform that offers an affordable open-source framework for smart contracts. POA leverages an independent group of block validators who maintain the transaction records and who are all licensed public notaries around the United States, which increases security while enabling a method of governance on the blockchain (Barinov et al., 2017). POA Network is a scalable, secure and cost effective solution for enabling CICs for micro, small and medium businesses. For more information visit [https://poa.network/](https://poa.network/). In order to connect Kenyan CICs to DIA we are using a version of POA that has a native DAI token: xDAI ([https://poa.network/xdai](https://poa.network/xdai)).


### 2.4 Price Stability and Continuous Liquidity

As blockchain related markets have demonstrated in recent years, the adoption of a currency by a community _can_ create new wealth for that community, which further increases as the currency adoption grows. This model dictates that the community currency’s price will fluctuate according to the adoption trend which can be contradictory to the need for price stability in a currency. 

The two key sources of price stability for CICs are market price arbitrage and collateral systems. In the first case as connected CICs begin to change in relative value the price advantage of one CIC over another will be taken advantage of by users to reduce costs (arbitrage). In this process, the token with a lower exchange value will experience more conversions increasing the token exchange price once again. 

In the second case each CIC reserve contains a national currency exchangeable stable token (such as DAI). This reserve amount offers a buffer to rapid price fluctuations by being able to absorb or emit CICs based on market demands. Extraction to fiat (National Currency) can also be further restricted to make CICs unattractive to pump and dump schemes and high volatility. Extraction can be time- and volume-locked such that only a percentage of one’s balance can be liquidated (to reserves) over a designated period of time, which translates to the ability to liquidate one’s balance over a long term period. This liquidation can also be restricted based on the exchange rate of the CIC. This ensures the continued availability of collateral for a reserve token, and that CIC holders will benefit financially from the long-term growth of the currency.

A reserve token’s unique value is that it can connect CICs together and give them a relative price to each other with or without any Stable token (DAI) reserve. Then when a token is added to the reserve of a CIC, connected CICs now have a gateway to that reserve (i.e. DAI -> National Currency) - and their exchange value to reserve will vary based on how much stays in reserve - but CICs local value to each other is based on their relative amounts of the reserve tokens. Communities can create their own media of exchange and link them together without national currencies - while providing timely, parameterized liquidity to national currency when available. 

_Lets say a vendor can no longer redeem their community currency for Kenyan Shillings/Mpesa eMoney. Won't that limit circulation and cause the local markets to stop using it?_

If there is no demand on those local tokens (against National Currency) then eventually its exchange value to National currency will drop so low that it is no longer worth-while to exchange. But the supply of these tokens need not diminish to zero and the amount of Community Inclusion Currency you can buy for National Currency will be very high at that point. Hence if there is <span style="text-decoration:underline;">any</span> motivation at all for local acceptance conversion from National Currency to Community currency will at some point be advantageous. 

For humanitarian aid purposes, injecting funds into a tokens reserve in order to give a fiat off-ramp - serves the purpose of external liquidity and parametrically injecting support for marginalized communities based on transaction data. Once those reserves are sufficiently reduced - the community can discontinue use of the Community Currency or continue trading it among themselves.

Social Collateral: Proper implementation requires some level of guarantee from goods or services in the local community (backing/employer of last resort). This backing could be local taxation (via negative interest rates and blockchain voting systems). This backing could be a cooperative maize mill or child care. These backers and their goods and services establish trust in their own CICs - before any large injections of seed funds reserve by donors - the community has to show SDG related trade (see RICCs as an example below where we focus on Refugee employment via transaction data)

In summary, the network of Community Inclusion Currencies gives people the ability to mint their own currencies and trade outside the bounds of scarce national currencies while also creating doorways to stable fiat exchange. In order to slow and balance this exchange out to fiat there are several mechanisms like the bonding curves and overall volume limits on users and the system as a whole. As the reserve pool grows (through demand on the CIC and community savings) we can limit the extraction from that pool by a % of it's growth, ensuring steady increases in value.

Note that beyond a system of connected circulating vouchers, in order to encourage the circulation of the CICs, there are several key implementation and system tools for voting, taxation, basic income and demurrage (negative interest). Variable fees on transactions can be introduced that depend both on how long the tokens have been stagnate and the volume being traded. These holding fees can be structured in various ways using smart contracts, such as a variable percentage of token balances depending on the time since the last trade, scaled by the amount of the last trade compared to account balance. These transaction fees can be collected into a community fund account and a voting system established so that users holding the tokens can decide what happens with the fees. Options could include system maintenance, community programs, social security, or taxation. 


## 3. Seeding CIC Reserves


### 3.1 Connecting Community Currencies Together

While we can envision the organic growth of economies built of connected user-generated CICs, the unfettered market that forms based on this growth can generate an uncompetitive system in which early token developers become _de facto_ reserve providers. In order to establish systems where markets are inclusive and work more efficiently for currently economically marginalized communities, we propose the adoption of reserve-seeding as a humanitarian aid practice. Such a general reserve, we will call the CIC Reserve Token, can include a National Currency stable token (such as DAI) and used to seed CICs that use it to automatically link with each other. By staking these CIC Reserve Tokens to CICs, communities easily and freely have reserves and collateral systems for their token creation and bypass the initial need to purchase or organically develop market-connecting reserve tokens. The connection between these actors will be described below under the **CIC Network Ecosystem **section.

Sarafu in Kenya as an example is only an _initial_ reserve as communities with CIC creators are free to disconnect, add or build their own reserves, or have as many or few reserves as they wish. We envision CIC Reserve Tokens helping to bootstrap the development of a fully connected ecosystem of tokens that support ecologically responsible and sustainable development. 


### 3.2 Reserve Token Generation

CIC Reserve Token generation can be created with reserves in stable tokens from supporter contributions. The CIC Reserve Token’s main purpose is to seed initial collateral for CICs and not as a speculation tool. In addition to this market-connecting function, CICs also can reward users for sharing their information with donors to access impact data accrued through transactional records, surveys and audits. This data will form a key index that allows international aid organizations to measure impacts (see section 3.2.1) and decide if more support is needed or if they should sell off their CICs and move their CIC Reserve Tokens to stake them to another community. Donors will also be able to offer CICs toward SDG programs with desired impacts, developed by implementers upholding collectively-defined standards (Appendix B). The CIC Reserve Token’s supply will grow as more reserves (via donations) are added to it at. CIC holders will only be enabled to sell a percentage of the growth of their tokens each year out to National Currencies.

Contributions by supporters via purchase of CICs go toward developing stable backing (by adding to reserves) increasing the value of CICs while also connecting CICs together. These CICs can be donated to the community to support SDG-related programs. Negative interest will form a community fund for participatory budgeting  as a sustainable local funding mechanisms. Finally, CIC transaction data combined with local surveys and audits will provide proof of impact accessible for CIC Token holders. 


## 3. Use Cases

While there are several potential uses listed in Appendix A, we will focus in this section on economically marginalized communities who have the most to gain from the potential of stabilizing their economies through accessing credit without the burden of debt and the monetization of their productive capacity.


### 3.1 Aid Supported Marginalized Communities

Several community-based organizations in Kenya developed community currencies with the assistance of Grassroots Economics Foundation in order to exchange goods and services in response to chronically lacking supplies of national currencies. These CCs (trading via paper vouchers until 2018) have been converted into pilot mobile-phone-based CIC systems, which enables them to develop regional CIC Reserves so that they can exchange with their neighbor communities. The impact data on local trade and other social and environmental metrics is generated on a blockchain and is validated by academics and researchers from reputable universities around the world. Chief among these preliminary findings is the compelling impacts of CC systems on food security in marginalised communities. Grassroots Economics Foundation will continue to publish these results as they are generated at [http://grassrootseconomics.org/research](http://grassrootseconomics.org/research).

Typical implementation strategy in marginalized communities involves: 



1. Cultural and socio-economic assessment - feasibility study for CIC injection model.
2. System customization for various market demographics, languages and cultures for CIC injection models as well as front-end systems. Access to create, trade and convert tokens is built into feature-phone systems (USSD) that enable people to hold and manage wallets without internet access.
3. Provision of aid funding to further seed initial CIC Reserves in the form of donations or cash and voucher assistance program. 
4. Community group development of a voucher (CIC) for audited productive capacity, valued initially 1:1 with the national currency in reserve (as DAI). These vouchers are injected into circulation in various ways, such as through local group operational costs, zero-interest credit, SDG programs, and airdropping to community members. Local communities begin social backing with their goods and services and add to their CIC Reserves.
5. Enabling CIC holders to exchange for national currencies through CIC reserves and for funding to be added locally and externally to CIC reserves based on market incentives and impact metrics.
6. Local groups train neighboring groups to use CIC with peer training incentivised by growing the local CIC market.

Once implemented, two CICs connecting to a common CIC Reserve are convertible to each other. This means that if the market is too small in one community they can now import from or export to another community. Community A importing from community B will cause some of the reserve of CIC A to flow into CIC B, Which will cause CIC B’s reserve to increase and CIC A’s reserve to drop. This change in reserve will reflect in the CICs relative pricing. Because community B is exporting, their CIC’s value will increase, and community A’s CIC’s value will decrease as it stabilizes the stable token A. This market balancing effect establishes a more inclusive and sustainable alternative for financing development, and even more remarkably, mitigating the trade imbalance and inequality persistently reproduced within current monetary systems.


### 3.2 Impact Model

The amount of trade in a community’s local market can be approximated as the aggregate sales revenue of all formal and informal businesses in the market over a period of time. The amount of national currency available to trade with is a function of its starting or nominal level, the amount of exports of labour, negatively correlated to the amount of imports of goods and other spending in the external market. The maximum amount of trade possible with limited supply of currency and businesses has an upper limit proportional to the amount of currency available in the community (Gesell, 1958). In the case where CC is injected into a community, it multiplies the effect by filling the gaps of existing national currency on total sales, which causes trade to reach a peak or optimal market faster. 

While Community Currencies are theoretically a powerful tool in developing local credit and market stability, their effectiveness is also dependent on the size and nature of existing local markets. In agreement with these findings, Porter (2000), Briguglio (2009) and Poulton (2006) suggest that a key factor in empowering resilient local economies with a stable balance of trade is developing import-replacing local production and service sectors. While the CCs studied in Kenya suggest that CC’s effectiveness depends on existing business demographics, further studies should attempt to measure the rate at which markets grow their local production and service sectors due to CC usage. By connecting CIC’s together there is the further potential to expand the number of new businesses interacting and increase trade balance by providing increased liquidity across multiple markets. The effective credit created in this system is the amount of reserve multiplied by the leverage of the CIC (their reserve ratio) multiplied by the increased utility of the CIC compared to National currencies. The risk associated with issuing more local CICs than reserve in Sarafu or National Currencies is offset by the CICs backing in and demand for local goods and services.

In the National Currency collateralized model for CICs (section 2.6), there is the potential to see both a market liquidity increase as well as CIC price stability. Further research could help to refine this model and show the full effects of community currency on economies, environments and society through randomized control trials (RCTs), for instance with economic surveys triangulated via transactional data. These topics and others require in-depth analysis from a consortium of universities and researchers.


#### 3.2.1 Proof of Impact for the UN Sustainable Development Goals

Community Inclusion Currencies (CICs) flowing through communities, geographic regions and municipalities can provide both qualitative and quantitative measurements for economic, environmental, and social indicators and impacts. Measurements of CIC transactions and user-contributed demographics, as well as third-party audit and survey data, can be packaged into valuable indices for development and used as standards (Appendix B) for proof of impact related to the Sustainable Development Goals (SDGs). SDG impacts can have various measurements using CICs blockchain transaction data as well as audit and survey data for each of the 17 SDGs ([https://en.wikipedia.org/wiki/Sustainable_Development_Goals](https://en.wikipedia.org/wiki/Sustainable_Development_Goals)), such as:



1. **No Poverty: **CIC trade per capita per unit of time. _The inclusive design of CIC systems has established unprecedented access to empirical data from informal “shadow” economies which  are the largest, most significant sectors in many low-income countries,  particularly in regard to serving the most deprived and marginalised segments of the population._
2. **No Hunger:** CIC trade for food and supply chain strength._ CIC trade systems provides multi-level performance indicators for bottom-of-the-pyramid food commodity markets, which can help us gain a comprehensive understanding of factors that govern the capacity of the poor to participate as both producers and consumers in food value chains._
3. **Health**: CIC trade for health services_ offers more relevant data for pro-poor health policy in regard to the economics, scalability and accessibility of essential health services.  _
4. **Education**: CIC trade for school fees and related educational activities such as teacher salaries. _The CIC system is suitably designed to assess the overlapping dimensions of development that impact equitable access to education._  
5. **Gender Equality**: The relative amount of CIC trade for various genders. _Gender-disaggregated CIC data can be analyzed to understand outcomes such as women’s access to sexual and reproductive health care, enabling technology, and economic resources._
6. **Clean Water**: CIC trade related to affordability and accessibility of water. _CIC data can improve _geographical_ targeting and contextual relevance of investments in creating access to potable water to better account for the heterogeneous nature of poor communities._
7. **Sustainable and Modern Energy**:_ _CIC trade spent on solar and other renewable energies. _Trade data can be disaggregated to distinguish access and affordability of both electricity and renewable energy for underserved_ _bottom-of-the-pyramid communities._ 
8. **Economic Health**: Overall CIC trade in the community per capita and supply chain strength. _CIC is creating access to largely unavailable economic information (with _substantial_ policy implication) from employment in the informal sector, which represents a significant 66% of employment in Sub-saharan Africa. Trade data helps indicate missing resources and businesses inside communities._
9. **Innovation and Infrastructure**: CIC trade related to infrastructure, public works/roads, and construction. _CIC systems are indicative of access to technological infrastructure, financial services, and affordability of credit for ‘unbanked’ micro and small-scale business entrepreneurs. Trade data can also be triangulated with other national and international metrics to assess the impact of national investments in transport infrastructure and industry on livelihoods at the bottom of the pyramid. _
10. **Reduced Inequality**: Measuring community self-sufficiency and the Gini Index of CIC wallet holders based on their total balances and trade volume, availing information on economic growth and inclusivity of monetary systems.   
11. **Sustainable Communities**: CIC community fund size and usage, CIC taxation payments and the market volatility, with valuation for economics resilience and sustainability indicators. 
12. **Responsible Consumption**: CIC circulation rates for “responsible” transactions per day per capita, which can also be assessed to track wastes and inefficiencies in commodity markets.  
13. **Climate Action**: Datasets for CIC usage and collection** can be utilised to evaluate the influences and impact of disaster risk reduction policy and  programs on household adaptive capacity. 
14. **Life Below Water**: Datasets for CIC usage and collection for mariner resources which can be utilised to better understand factors influencing sustainable production and consumption within small-scale fisheries. 
15. **Life on Land**: Data for CIC usage and collection can be triangulated with other datasets to improve the relevance of policy frameworks and subsequent expenditure on biodiversity conservation and sustainable use of terrestrial ecosystems.
16. **Peace and Justice**: Datasets for CIC usage and collection for peace- and justice-related programs create a practical understanding of the systemic impact and demand for peace and justice.
17. **Partnerships**: Community size, number of CIC traders, connected communities and supporters. CIC trade activates excess capacities within communities in developing countries, which has policy implication for domestic resource mobilisation, debt sustainability and expansion of  inclusive trade network and market. 

_**CIC collection refers to donations, fees and taxation. _

Measurements include calculations, relative change over time, comparison to control groups and other CIC-using communities, as well as other indexes. As international aid moves more and more from prescriptive to evidence-based interventions, CICs give the aid industry the fine granularity needed to both observe the impact of interventions and access a comprehensive evidence base for decision-making in development programs and target aid to specific communities and individual beneficiary wallet holders. 


## 5. Summary


### 5.1 Seeding the decentralized economy of CICs

By focusing on communities as the core units of the economy, and enabling them to develop and trade without the burden of interest-bearing credit, blockchain technologies have the potential to end the core structural causes of institutionalized world poverty and provide financial systems to avert or minimise the human cost of monetary and financial crises. Beyond creating the first decentralized market for cryptocurrencies in marginalized communities, Grassroots Economics is working to enable communities and supporting organizations around the world to create their own Community Inclusion Currencies and use them as Proof of Impact for development. Community Inclusion Currencies are a foundational element in the mission toward reaching UN Sustainable Development Goals. 

While still in its trial phases, a conservative estimate based on early data is that roughly 20x leverage of donated funds into CIC Reserves is already possible. This is the level of critical mass of connected markets we are looking to bootstrap self-sustaining grassroots economies. For each $1 USD of contribution we expect to see 20x the impact compared to national currency-based SDG funding. This includes measurable increased across the 17 SDGs as described in section 2.7.1. 

The ability to scale humanitarian solutions to the 2+ billion people living in extreme poverty and subject to environmental disaster has been elusive due to intrinsic problems with the current economic system. Looking into the future with this in mind, CICs would be enough to fill the World Bank's Credit Gap estimated at 2 trillion USD. CICs, backed by local production and circulating more rapidly than fiat currencies, could, in turn, fill the UN’s funding gap for delivering Sustainable Development Goals.

Community Currencies have been piloted (via paper vouchers such as Bangla-Pesa) since 2010 in Kenya to solve the intrinsic problems of unsustainable development funding, and the first 5000 small businesses in marginalized communities have already started piloting CICs for basic needs and SDGs. 

Open platforms and a global movement are needed to build on these protocols and frameworks and support communities worldwide to develop their own economies. Consider the profound potential of partnering in a global effort to build the world's first truly decentralized economic system from the bottom up, and end poverty in our lifetime.


## 6. Acknowledgments

We would like to express our gratitude to the many people and organizations who supported Grassroots Economics’ mission over the years, culminating in this paper. A special thanks to the late Bernard Lietear for his profound inspiration and life’s work. Thanks also to Eyal Hertzog, Adam, Bornstein, Paula Gil Baizan, Fennie Wang, Nick Williams, Holger Hoffmann-Riem, Stephen DeMeulenaere, Ester Barinaga, Carmen Mauk, Jem Bendell, Marc Barasch, Susan Witt, Thomas Greco, Alex Olivas, Matthew Slater, Scott Morris, Edgar Kampers, Tatiana Rubiano, Marion Cauvet, Martine Visser, Elen Stecca, Tat Lam, Griss Gee, Orit Hertzog, Asaf Shachaf, Yudi Levi, Omry Rozenfeld, Nate Hindman, Roni Gur, Miri Bickel, Dotan Elnatan, Mati Levi, Jens Martignoni, Ariel Lashansky, Tomer Bariach, Dann Sillen, Bitange Ndemo, Sven Duyx,  Erick Brenes, Georgina Gomez, Kibet Yegon, Shams Kairys, Kevin D'Arbela, Damaris Njoroge, as well as the teams of Grassroots Economics, BProtocol Foundation, POA.network, Greenworld Campaign, Stichting DOEN, Triodos Bank, Sempo, Lush Cosmetics, Segal Family Foundation, and LocalCoin. Your support and feedback has been crucial to us in improving our work and this document. Thank you! 


## Appendix A: Additional Use Cases


### A.1 Universal Basic Income (UBI)

Blockchains have been proposed as potential solutions for creating UBI in that they enable a medium of exchange to be directly provided to communities and individuals with little or no need for distributors. Via CICs and regional reserve tokens, taxes, programmed inflation, fees, demurrage and other mechanisms can be created to collect and automatically re-distribute tokens. This creates _local_ mechanisms for UBI and bypasses the dependency problem of UBI from foreign sources. While CCs alone give little room for UBI being injected from exogenous sources, CICs can enable communities to increase their collateral and inject development funding. In addition, creating CICs with integrated UBI systems creates an incubator for local market development.

Those wishing to develop a UBI may begin by creating a CIC in their community. This CIC would have a transaction fee system that collects tokens and automatically disburses them to the community. This would be a simple transparent tax (e.g. negative interest rate) that is reinvested in the community. Without capacity for significant tax volume to fill the needs of a UBI in some marginalized areas, temporary external support along with token inflation (the issuance of newly created tokens) could also serve to support a UBI. 

For example, a community currency in Gran Canaria, Spain was built with UBI and has been providing for 5 years a universal unconditional basic income whose level is conditioned to the degree the individual has supported the community that month ([http://monedademos.es](http://monedademos.es)). 


### A.2 Refugee Inclusion 

Traditional aid development programs have failed to address the fundamental problems plaguing the economic infrastructure of marginalized communities around refugee camps. Traditional aid into these economies often creates unsustainable food systems and market dynamics that exacerbate poverty levels and reinforce the existing economic structure and exclusion of refugees. The bulk of the aid flows out of the community too quickly to provide lasting impact, while key community members and resources remain largely underutilized. Finally, there is simply not enough aid to go around - the ability to leverage existing aid into effective credit and attract private sector actors are key missing components. 

Poor communities don’t lack demand, or labour, or ideas. They lack a medium of exchange to deploy their underutilized resources. This is the core of our proposal for Refugee Inclusion Community Currencies (RICCs). 

**Objective: Leverage cash transfers into community currencies to strengthen refugee communities**

RICCs are blockchain-based tokens given directly to beneficiaries and accessible through feature phones. They are issued as vouchers for local goods and services based on the productive capacity of local communities and collateralized by Cash Transfer Program (CTP) funding. They may be exchanged for national currency based on the level of collateralization.

What is revolutionary about RICCs is that their supply is not limited 1:1 to national currency funds. This allows RICCs to be a sustainable medium of exchange even when CTP funding is scarce. They leverage funding and limit cashing out based on the growth of principal reserves, hence eliminating liquidity risk. They give communities a credit system that can expand beyond and outlast aid funds.

Community members will receive an initial injection of RICCs on their feature phones using Unstructured Supplementary Service Data (USSD) technology combined with blockchain scalability, tracking and security developed by MakerDAO, a private company specializing in blockchain technologies, and Grassroots Economics Foundation, a nonprofit building community currencies for thriving local economies. Beneficiaries then use these tokens to buy and sell goods and services that are underutilized when communities are cash poor. In this way, families can afford to pay tuition to keep children in school, buy more flour and vegetables, or get regular access to water. 



1. Donations and Cash Transfers fund the reserve for the creation of RICCs tokens.
2. RICCs tokens leverage the sustainability fund based on the growth of that fund through investment and stable token (DAI) interest rates.
3. Local communities are trained and empowered to ensure buy-in and understanding and RICCs are distributed for local barter trade among regional communities.
4. Local circulation of RICCs enables economic development and refugee integration and gives evidence for who should receive additional cash transfers.
5. Grassroots Economics Foundation as well as local third parties facilitate conversion of RICCs to national currencies for KYC’ed users.
6. Continuous incentives keep circulation flowing even when aid reserves are diminished. Note that the stability fund can be refilled by anyone.


### A.3 Trees and Asset Backing

When considering CICs as backed by future production, woodlots (trees planted for future harvest) have a clear value proposition as backing for CCs according to Hudon and Lietaer (2006). Carbon offsetting for indigenous tree planting could also have the same collateralizing effect for CICs. In this light, a tree-harvesting organization could create a token based on the value of the trees over their next harvest, e.g. 1000 trees planted could be used as collateral for their future revenue. These tree tokens in circulation prior to harvest could be used to promote more tree planting with community members. A farmer receiving the tokens could deposit them into long-term saving or utilise them commercially within the community. Aid organizations or investors wishing to support tree planting could hold or increase the reserves of these tokens, or their growth token equivalent, to support more token issuance for more tree planting. 

In Kenya a local cooperative accepts CICs for the use of its maize mill for grinding corn flour, and part of the CIC collected is utilized for Greenworld Campaign (the environmental NGO who helped develop the maize mill) reforestation and agroforestry community programs. In this case local cooperatives act as the collateral for community environmental programs. 


### A.3 Health

Aid organizations wishing to promote health could create a token backed by reserves in donated pharmaceuticals and clinics. These tokens could be offered to the elderly or as a universal health care system established in clinics that can redeem the tokens for pharmaceuticals or use them for local commerce. These tokens could also serve as a medium of exchange and a taxation system on that exchange that would make the aid organization’s local funding sustainable.


### A.4 Food Security

Poorly designed economies create unsustainable food systems, and poverty. Vulnerable food systems worldwide have no buffer against climate change when combined with the volatility of national and international markets. Because of their dependency on these markets, food enterprise profits do not produce enough regional development and instead funnel toward economic hubs. This causes a chronic lack of cash and credit for communities and the supply chain, which translates to vulnerability to environmental disaster, food insecurity, chronic poverty, and a lack of agricultural labor and investment. Integrating farms and organizations along supply chains into Community Inclusion Currencies helps build the resilience of the food system and incubates regional food providers and distributors from volatile market conditions. Food systems integrated into CICs would also have transactional transparency to measure efficiency along supply chains.


### A.5 National and Municipal Currencies

Governments may begin using CICs to create a source of local credit for development, as well as sustainable taxation. Each community within the governance structure could be linked to a regional reserve. Regionality is a natural choice for the human scale of these tokens. Regional tokens based on political units such as municipal governments could be a natural choice as a liquidity provider through the creation of regional reserve tokens. The CIC system creates a mechanism for Fractional Reserve, Banking Insurance, and Price Stability (section 2.6), which are all present in all levels of CICs described in this paper. This gives government the ability to provide stability and market growth while independent user-generated token markets seek to gain traction. 


## Appendix B: Standards for Implementers, Validators and Communities

We would like to engage partners in developing a set of standards for implementers who design and set up CICs, validators of impact data, as well as beneficiary communities receiving Sarafu reserves. These standards will be published and updated yearly, and used to direct donor contributions toward enhancing existing CICs and seeding new ones. The standard body will consist of the board of Grassroots Economics Foundation as well as voluntary holders of 5% or more of the Sarafu tokens in existence and their representatives. Groups of Sarafu holders may form into clusters of 5% or more for eligibility as a group or organizational Standard Board member.


### B.1:  Standards Outline 



*   **Protocol Standards **refer to various agreements on pricing between CICs as well as governance.
*   **Community Standards** refer to how a community governs, trains, and becomes eligible for various amounts of Sarafu reserves.
*   **Implementer Standards** refer to how CIC developers are selected and implement CIC programs with communities.
*   **Validator Standards** refer to how validators are selected and verify impacts based on blockchain, audit and survey data. These validation standards will follow the published indicators and a monitoring framework for the Sustainable Development Goals (Schmidt-Traub et. al  2017), and expand on them in reference to blockchain-based transaction data. 

While seeking to incorporate the wishes of all contributors, these standards will determine how, when and by whom Sarafu tokens are allocated, in alignment with the core principles of:



*   **Market Size (Critical Mass):** Seeding a vibrant network of connected CICs in order to balance trade and accelerate impacts.
*   **Ending Poverty:** Focusing support on underserved, marginalized, and low-income communities.
*   **Strong Backing:** CICs should be fundamentally backed by productive capacity of all kinds, but with a focus on local regenerative capacity and practices.
*   **Community Focus:** Enabling fair and communal ownership of CICs while monetising productive capacity of all participating members.
*   **Inter-Token Stability:** Ensuring stable CIC prices and markets through adequate risk assessment and collateral systems.


### B.2 **CIC Token Summary**



1. **Blockchain:** Sarafu (the Kenyan example) is currently using POA.Network, which offers quicker transactions and ultra-low transaction costs as well as a bridge to Ethereum and other blockchains. Note that pan-blockchain protocols and systems that allows transaction fees and all levels of system usage will need to be generated for communal ownership and management.
2. **Token reserve stability:** A CIC network token holds both an exchange protocol and reserves (in stable tokens). These reserves value should be decoupled from CICs themselves and stable against a basket of commodities.  
3. **Contributions:** Token holders can contribute by staking DAI into reserves and converting into community tokens (CIC) and holding those tokens as an investment or offering them to the community or community members based on SDG metrics.
4. **Seeding:** Humanitarian, development and SDG-related programs, implementers and communities can apply for CIC Network Token reserves based on impact data.
5. **Sales to reserve of CICs:** Only a percentage of the gains on CIC can be converted to other tokens or sold per month back to reserves.
6. **Data Access:** Users should own access to their own data via sovereign identity protocols. This data can be requested by researchers only upon allowance from the user and CICs can be offered as payment.
7. **Initial Supply:** Community Inclusion Currencies are created in supply for the area they are implemented in. They can start disconnected from stable token reserve or connected. Their price in exchange for Stable tokens like DAI will depend solely on their reserve to supply ratio using a bonding curve.


### B.3 CIC Network Ecosystems:



1. **Contributors **provide external funding in the form of crypto and/or national currencies to support or back CICs:
    1. **Donors/International Aid Organizations** provide seed funding for developing CICs, and monitor impact data used to further support emerging economies. 
    2. **Impact Investors** add reserve to CICs and hold the created CICs to offer collateral and speculate on economic growth. (With restrictions on cashing out)
2. **Service Providers** offer services that enable and further develop CICs without direct involvement:
    3. **Developers** provide software infrastructure and customizations for use in CICs, such as wallets, taxation integration, governance systems and marketplaces.
    4. **Stability Authorities **maintain stable CIC Reserve Tokens as well as develop new stable token and collateral mechanisms suited to particular communities. 
    5. **Standard Providers: **provide standards on reservesm governance, protocols, implementers, verifiers and more (see Appendix B).
3. **Implementers **are directly involved in developing and assisting CICs:
    6. **Community Groups** issue CICs and collateralize them with reserves as well as connect them to other CICs
    7. **Agents/Brokers** work with Liquidity Providers to build CICs and local and regional markets. 
    8. **Advocacy and Education teams** help organizations and communities around the world understand and develop their own CICs. 
    9. **Researchers **use CIC Network Tokens to access and analyse data from CICs to provide systematic understanding and policy recommendations for the emerging decentralized economy.
    10. **Auditors/Validators** verify and package transactional and survey data, and authenticate SDG impacts related to CIC usage.
    11. **Community Inclusion Currency Users **earn, or are given CICs as a local medium of exchange, and are incentivized by donors using stable and growth tokens to trade based on SDG impacts.


## References

Barinaga, E., Zapata Campos, MJ., Ruddick, W. 2018. Community currencies as grassroots monetary infrastructures for the economic commons. _7th LAEMOS Conference_ on “Organizing for resilience: scholarship in unsettled times”. IAE Business School, Buenos Aires, Argentina. March 21-24.

Barinov, I. et al. (2017). POA network - white paper. [https://github.com/poanetwork/wiki/wiki/POA-Network-Whitepaper](https://github.com/poanetwork/wiki/wiki/POA-Network-Whitepaper) 

Benartzi, G., Herzog, E., & Benartzi, G. (2017). Bancor protocol-white paper.

[https://about.bancor.network/protocol/](https://about.bancor.network/protocol/) 

Bendell, J., Slater, M., & Ruddick, W. (2015). Re-imagining money to broaden the future of development finance: what Kenyan community currencies reveal is possible for financing development (No. 2015-10). UNRISD Working Paper.

Briguglio, L., Cordina, G., Farrugia, N., & Vella, S. (2009). Economic vulnerability and resilience: concepts and measurements. Oxford development studies, 37(3), 229-247.

Gesell, S. (1958). The natural economic order. London: Owen.

GitHub: [http://github.com/GrassrootsEconomics](http://github.com/GrassrootsEconomics) 

Hayek, F. A. (1990). Denationalisation of money: the argument refined: an analysis of the theory and practice of concurrent currencies (Vol. 70). Institute of Economic Affairs.

Hirota, Y. (2013). Recent trend in complementary currencies in the world. Community Currency, 178-182.

Hudon, M., & Lietaer, B. (2006). " Natural savings": a new microsavings product for inflationary environments how to save forests with savings for and by the poor?. _Savings and development_, 357-380.

Kobayashi, S., Hashimoto, T., Kurita, K. I., & Nishibe, M. (2013). Correlation between currency consciousness among participants of community currency and its circulation. In The Proceedings of 2nd International Conference on Complementary Currency Systems (p. 12).

Lietaer, B., Arnsperger, C., Goerner, S., & Brunnhuber, S. (2012). Money and sustainability. _The Missing Link. Axminster: Triarchy Press Ltd_.

North, P. (2005). Scaling alternative economic practices? Some lessons from alternative currencies. Transactions of the Institute of British Geographers, 30(2), 221-233.

Porter, M. E. (2000). Location, competition, and economic development: Local clusters in a global economy. Economic development quarterly, 14(1), 15-34.

Ruddick, W. O., Richards, M. A., & Bendell, J. (2015). Complementary currencies for sustainable development in Kenya: The Case of the Bangla-Pesa. International Journal of Community Currency Research, 19, 18-30.

Ryan-Collins, J., Greenham, T., Werner, R. A., & Jackson, A. (2012). Where Does Money Come from?, new economics foundation.

Stodder, J. (2000). Reciprocal exchange networks: implications for macroeconomic stability. In Engineering Management Society, 2000. Proceedings of the 2000 IEEE (pp. 540-545). IEEE.

Schmidt-Traub, G., De la Mothe Karoubi, E., & Espey, J. (2015). Indicators and a Monitoring Framework for the Sustainable Development Goals: Launching a Data Revolution for the SDGs. Sustainable Development Solutions Network.

Wikipedia authors. Sarafu-Credit system [https://en.wikipedia.org/wiki/Sarafu-Credit](https://en.wikipedia.org/wiki/Sarafu-Credit) 

Yamazaki, S. (2013). Community Currency as a tool of regional revitalization (in Japanese), Osaka: Osaka Municipal Universities Press.


<!-- Docs to Markdown version 1.0β17 -->
